use crate::content;
use cgmath::{Deg, Point2};

/// The location of a UI element, in one of a few
/// possible coordinate systems.
///
/// Positive Y always points up,
/// positive X always points right.
#[derive(Debug, Clone)]
pub enum AnchoredUiPosition {
	/// Position of this sprite's center,
	/// relative to the nw corner of the window.
	NwC(Point2<f32>),

	/// Position of this sprite's nw corner,
	/// relative to the nw corner of the window.
	NwNw(Point2<f32>),

	/// Position of this sprite's ne corner,
	/// relative to the nw corner of the window.
	NwNe(Point2<f32>),

	/// Position of this sprite's sw corner,
	/// relative to the nw corner of the window.
	NwSw(Point2<f32>),

	/// Position of this sprite's se corner,
	/// relative to the nw corner of the window.
	NwSe(Point2<f32>),

	/// Position of this sprite's ne corner,
	/// relative to the ne corner of the window.
	NeNe(Point2<f32>),
}

impl AnchoredUiPosition {
	pub fn to_anchor_int(&self) -> u32 {
		match self {
			Self::NwC(_) => 0,
			Self::NwNw(_) => 1,
			Self::NwNe(_) => 2,
			Self::NwSw(_) => 3,
			Self::NwSe(_) => 4,
			Self::NeNe(_) => 5,
		}
	}

	pub fn position(&self) -> &Point2<f32> {
		match self {
			Self::NwC(x)
			| Self::NwNw(x)
			| Self::NwNe(x)
			| Self::NwSw(x)
			| Self::NwSe(x)
			| Self::NeNe(x) => x,
		}
	}
}

// TODO: remove
/// A sprite that represents a ui element
#[derive(Debug, Clone)]
pub struct UiSprite {
	/// The sprite to draw
	pub sprite: content::SpriteHandle,

	/// This object's position, in logical (dpi-adjusted) pixels
	pub pos: AnchoredUiPosition,

	/// This sprite's color will be multiplied by this value.
	/// If this is None, color will not be changed.
	pub color: Option<[f32; 4]>,

	/// The size of this sprite, in logical (dpi-adjusted) pixels
	pub dimensions: Point2<f32>,

	/// This sprite's rotation, measured ccw
	pub angle: Deg<f32>,
}
